# S3 analyst

[![pypi shield](https://img.shields.io/pypi/v/s3_analyst.svg)](https://pypi.python.org/pypi/s3_analyst)
[![Build Status](https://travis-ci.org/Tofull/devops-coding-challenge.svg?branch=master)](https://travis-ci.org/Tofull/devops-coding-challenge)
[![Documentation Status](https://readthedocs.org/projects/devops-coding-challenge/badge/?version=latest)](http://devops-coding-challenge.readthedocs.io/en/latest/?badge=latest)
[![Updates](https://pyup.io/repos/github/Tofull/devops-coding-challenge/shield.svg)](https://pyup.io/repos/github/Tofull/devops-coding-challenge/)
[![Python 3](https://pyup.io/repos/github/Tofull/devops-coding-challenge/python-3-shield.svg)](https://pyup.io/repos/github/Tofull/devops-coding-challenge/)




An AWS S3 storage analysis tool.

- Free software: GNU General Public License v3
- Documentation: [http://devops-coding-challenge.readthedocs.io](http://devops-coding-challenge.readthedocs.io).


## Features

* TODO

## Credits

This package was created with Cookiecutter _and the `audreyr/cookiecutter-pypackage`_ project template.

[Cookiecutter](https://github.com/audreyr/cookiecutter)

[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)

